componenttools.get_improper_descendents_of_component
====================================================

.. autofunction:: abjad.tools.componenttools.get_improper_descendents_of_component.get_improper_descendents_of_component
   :noindex:
